"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const sfpowerkit_1 = require("../../../sfpowerkit");
const poolHydrateImpl_1 = __importDefault(require("../../../impl/pool/scratchorg/poolHydrateImpl"));
// Initialize Messages with the current plugin directory
command_1.core.Messages.importMessagesDirectory(__dirname);
// Load the specific messages for this file. Messages from @salesforce/command, @salesforce/core,
// or any library that is using the messages framework can also be loaded this way.
const messages = command_1.core.Messages.loadMessages("sfpowerkit", "scratchorg_poolhydrate");
let Hydrate = /** @class */ (() => {
    class Hydrate extends command_1.SfdxCommand {
        async run() {
            sfpowerkit_1.SFPowerkit.setLogLevel("DEBUG", false);
            await this.hubOrg.refreshAuth();
            const hubConn = this.hubOrg.getConnection();
            this.flags.apiversion =
                this.flags.apiversion || (await hubConn.retrieveMaxApiVersion());
            let hydrateImpl = new poolHydrateImpl_1.default(this.hubOrg, this.flags.apiversion, this.flags.tag, this.flags.mypool, this.flags.allscratchorgs);
            let result = await hydrateImpl.execute();
            if (!this.flags.json) {
                if (result.length > 0) {
                    this.ux.log(`======== Scratch org Deleted ========`);
                    this.ux.table(result, ["orgId", "username"]);
                }
                else {
                    sfpowerkit_1.SFPowerkit.log(`${this.flags.tag} pool has No Scratch orgs available to delete.`, sfpowerkit_1.LoggerLevel.INFO);
                }
            }
            return JSON.stringify(result);
        }
    }
    Hydrate.description = messages.getMessage("commandDescription");
    Hydrate.requiresDevhubUsername = true;
    Hydrate.examples = [
        `$ sfdx sfpowerkit:pool:hydrate -t core `,
        `$ sfdx sfpowerkit:pool:hydrate -t core -v devhub`,
        `$ sfdx sfpowerkit:pool:hydrate -t core -v devhub -m`,
        `$ sfdx sfpowerkit:pool:hydrate -t core -v devhub -m -a`
    ];
    Hydrate.flagsConfig = {
        tag: command_1.flags.string({
            char: "t",
            description: messages.getMessage("tagDescription"),
            required: true
        }),
        mypool: command_1.flags.boolean({
            char: "m",
            description: messages.getMessage("mypoolDescription"),
            required: false
        }),
        allscratchorgs: command_1.flags.boolean({
            char: "a",
            description: messages.getMessage("allscratchorgsDescription"),
            required: false
        })
    };
    return Hydrate;
})();
exports.default = Hydrate;
//# sourceMappingURL=hydrate.js.map